const number_input_props = (message: string, precision: number = 0, nonzero: boolean = false) => {
  return {
    type: "number",
    step: 1,
    precision,
    min: 0, //! 这个选项似乎没有用
    span: 8,
    rules: [{
      required: true,
      message,
      trigger: 'blur'
    }, {
      validator: (_: any, v: number, callback: Function) => {
        callback((v > 0 || v === 0 && !nonzero) ? undefined : new Error(nonzero ? "应当为正数" : "应当为非负数"))
      },
      trigger: 'blur'
    }]
  }
}

export default {
  column: [
    {
      label: '产品名称',
      prop: 'name',
      type: 'input',
      span: 12,
      row: true,
      rules: [{
        required: true,
        message: "请输入产品名称",
      }]
    }, {
      label: '产品描述',
      prop: 'desc',
      type: 'textarea',
      minRows: 3,
      maxRows: 5,
      row: true,
    }, {
      label: "价格(￥)",
      prop: "price",
      ...number_input_props("请输入产品价格", 2, true),

    }, {
      label: "运费(￥)",
      ...number_input_props("请输入运费价格", 2),
      prop: "deliverPrice",
      row: true,
    }, {
      label: "库存(件)",
      prop: "stockAmount",
      ...number_input_props("请输入库存数"),
      // }, {
      //   label: "售出(件)",
      //   prop: "soldAmount",
      //   ...number_input_props("请输入售出量"),
      row: true,
    }, {
      label: "商品类型",
      prop: "kind",
      span: 8,
    }, {
      label: "商品平台",
      prop: "platform",
      span: 8,
      row: true,
    }, {
      label: "商品分类",
      prop: "goodsTypeList",
      formslot: true,
      span: 24,
      row: true,
    }, {
      label: '封面图片',
      prop: 'cover',
      type: 'upload',
      listType: 'picture-card',
      span: 24,
      accept: 'image/png, image/jpeg',
      limit: 1,
      fileSize: 5 * 1024,
      propsHttp: {
        res: 'data'
      },
      tip: '只能上传jpg/png图片，且不超过5MiB（暂时没用）',
      action: ''
    }
  ]
}