import axios, { AxiosInstance } from 'axios'
import { Message } from 'element-ui'

const BASEURL = process.env.VUE_APP_BASE_API || ""

interface Utilities {
  makeurl(path: string, query?: Record<string, any>): string
}

const httpx_request = axios.create({
  timeout: 1000 * 5,
  // withCredentials: true,
  headers: {
    'Content-Type': 'application/json; charset=utf-8'
  }
})

const httpx_utility: Utilities = {
  makeurl(path, query = {}): string {
    if (!query) {
      return BASEURL + path
    } else {
      const query_str = new URLSearchParams(query).toString()
      return BASEURL + path + "?" + query_str
    }
  }
}

export const httpx = Object.assign(httpx_request, httpx_utility)

httpx.interceptors.response.use(
  (response) => {
    console.log(response.status, response.data)
    if (response.data.code >= 0) {
      response.statusText = response.data.msg;
      response.data = response.data.data;
      if ((response.data?.retCode || "0000") !== "0000") {
        //! 如果后端能更规范一些就好了
        Message({
          message: response.data.retMsg,
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex',
        })
      }
      return response;
    } else {
      Message({
        message: response.data.msg,
        type: 'error',
        duration: 1500,
        customClass: 'element-error-message-zindex'
      })
      return Promise.reject()
    }
  }, (error) => {
    switch (error.response.status) {
      case 400:
        Message({
          message: error.response.data,
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
        break
      case 401:
        // clearLoginInfo()
        // router.push({ name: 'login' })
        break
      case 405:
        Message({
          message: 'http请求方式有误',
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
        break
      case 500:
        Message({
          message: '服务器出了点小差，请稍后再试',
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
        break
      case 501:
        Message({
          message: '服务器不支持当前请求所需要的某个功能',
          type: 'error',
          duration: 1500,
          customClass: 'element-error-message-zindex'
        })
        break
    }
    return Promise.reject(error)
  }
)

export default httpx
export { AxiosPromise, AxiosResponse } from "axios"